pub enum Shapes {
Constant(Constant),
Linear(Linear),
Quadratic(Quadratic),
Cubic(Cubic),
}Expand description
An enum grouping all of the different shapes (beziers) available. Constant can never be built, but needs to be defined because the other types use it.
Variants
Implementations
Sourceimpl Shapes
impl Shapes
pub fn coeffs(&self) -> &[Vec2]
pub fn coeffs_mut(&mut self) -> &mut [Vec2]
pub fn set_last_point(&mut self, n: Vec2)
pub fn translate_by(&mut self, dir: Vec2)